@@ -33,15 +33,11 @@
 #include "woptions.h"
 #include "defaults.h"
 #include "wedittags.h"
+#include <richedit.h>
 
 #if __GNUC__
 #include <errno.h>
 #include <strings.h>
-/* From richedit.h */
-#define SCF_ALL 0x0004
-#define CFM_CHARSET 0x08000000
-#else
-#include <richedit.h>
 #endif
 
 /* Imports from winboard.c */
@@ -66,6 +62,7 @@ extern HWND commentDialog;
 extern char installDir[];
 extern HWND hCommPort;    /* currently open comm port */
 extern DCB dcb;
+extern BOOLEAN chessProgram;
 
 /* types */
 
@@ -96,6 +93,7 @@ VOID PaintSampleSquare(
     COLORREF squareColor, 
     COLORREF pieceColor,
     COLORREF squareOutlineColor,
+    COLORREF pieceDetailColor,
     BOOL     isWhitePiece,
     BOOL     isMono,
     HBITMAP  pieces[3] 
@@ -169,13 +167,16 @@ GeneralOptionsDialog(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
 
 #undef CHECK_BOX
 
-    if (appData.icsActive || appData.noChessProgram) {
-      EnableWindow(GetDlgItem(hDlg, OPT_AutoFlag), (BOOL)appData.icsActive);
-      EnableWindow(GetDlgItem(hDlg, OPT_AutoFlipView),(BOOL)appData.icsActive);
-      EnableWindow(GetDlgItem(hDlg, OPT_PonderNextMove), FALSE);
-      EnableWindow(GetDlgItem(hDlg, OPT_PeriodicUpdates), FALSE);
-      EnableWindow(GetDlgItem(hDlg, OPT_ShowThinking), FALSE);
-    }
+    EnableWindow(GetDlgItem(hDlg, OPT_AutoFlag),
+		 appData.icsActive || !appData.noChessProgram);
+    EnableWindow(GetDlgItem(hDlg, OPT_AutoFlipView),
+		 appData.icsActive || !appData.noChessProgram);
+    EnableWindow(GetDlgItem(hDlg, OPT_PonderNextMove),
+		 !appData.noChessProgram);
+    EnableWindow(GetDlgItem(hDlg, OPT_PeriodicUpdates), 
+		 !appData.noChessProgram && !appData.icsActive);
+    EnableWindow(GetDlgItem(hDlg, OPT_ShowThinking), 
+		 !appData.noChessProgram);
     return TRUE;
 
 
@@ -278,6 +279,7 @@ PaintSampleSquare(
     COLORREF squareColor, 
     COLORREF pieceColor,
     COLORREF squareOutlineColor,
+    COLORREF pieceDetailColor,
     BOOL     isWhitePiece,
     BOOL     isMono,
     HBITMAP  pieces[3] 
@@ -286,7 +288,7 @@ PaintSampleSquare(
   HBRUSH  brushSquare;
   HBRUSH  brushSquareOutline;
   HBRUSH  brushPiece;
-  HBRUSH  brushPieceOutline;
+  HBRUSH  brushPieceDetail;
   HBRUSH  oldBrushPiece;
   HBRUSH  oldBrushSquare;
   HBITMAP oldBitmapMem;
@@ -321,7 +323,7 @@ PaintSampleSquare(
   brushSquare         = CreateSolidBrush(squareColor);
   brushSquareOutline  = CreateSolidBrush(squareOutlineColor);
   brushPiece          = CreateSolidBrush(pieceColor);
-  brushPieceOutline   = CreateSolidBrush(RGB(0,0,0));
+  brushPieceDetail    = CreateSolidBrush(pieceDetailColor);
 
   /* 
    * first draw the rectangle 
@@ -340,16 +342,43 @@ PaintSampleSquare(
 	   isWhitePiece ? SRCCOPY : NOTSRCCOPY);
     SelectObject(hdcTemp, oldBitmapTemp);
   } else {
-    oldBitmapTemp = SelectObject(hdcTemp, 
-			     isWhitePiece ? pieces[WHITE] : pieces[SOLID]);
-    oldBrushPiece = SelectObject(hdcMem, brushPiece);
-    BitBlt(hdcMem, x, y, SAMPLE_SQ_SIZE, SAMPLE_SQ_SIZE, 
-	   hdcTemp, 0, 0, 0x00B8074A);
     if (isWhitePiece) {
-	SelectObject(hdcMem, brushPieceOutline);
-	SelectObject(hdcTemp, pieces[OUTLINE]);
-	BitBlt(hdcMem, x, y, SAMPLE_SQ_SIZE, SAMPLE_SQ_SIZE, 
-	       hdcTemp, 0, 0, SRCAND);
+      oldBitmapTemp = SelectObject(hdcTemp, pieces[WHITE]);
+      oldBrushPiece = SelectObject(hdcMem, brushPiece);
+      BitBlt(hdcMem, x, y, SAMPLE_SQ_SIZE, SAMPLE_SQ_SIZE, 
+	     hdcTemp, 0, 0, 0x00B8074A);
+#if 0
+      /* Use pieceDetailColor for outline of white pieces */
+      SelectObject(hdcTemp, pieces[OUTLINE]);
+      SelectObject(hdcMem, brushPieceDetail);
+      BitBlt(hdcMem, x, y, SAMPLE_SQ_SIZE, SAMPLE_SQ_SIZE, 
+	     hdcTemp, 0, 0, 0x00B8074A);
+#else
+      /* Use black for outline of white pieces */
+      SelectObject(hdcTemp, pieces[OUTLINE]);
+      BitBlt(hdcMem, x, y, SAMPLE_SQ_SIZE, SAMPLE_SQ_SIZE, 
+	     hdcTemp, 0, 0, SRCAND);
+#endif
+    } else {
+#if 0
+      /* Use pieceDetailColor for details of black pieces */
+      /* Requires filled-in solid bitmaps (BLACK_PIECE class); the
+	 WHITE_PIECE ones aren't always the right shape. */
+      oldBitmapTemp = SelectObject(hdcTemp, pieces[BLACK]);
+      oldBrushPiece = SelectObject(hdcMem, brushPieceDetail);
+      BitBlt(hdcMem, x, y, SAMPLE_SQ_SIZE, SAMPLE_SQ_SIZE, 
+	     hdcTemp, 0, 0, 0x00B8074A);
+      SelectObject(hdcTemp, pieces[SOLID]);
+      SelectObject(hdcMem, brushPiece);
+      BitBlt(hdcMem, x, y, SAMPLE_SQ_SIZE, SAMPLE_SQ_SIZE, 
+	     hdcTemp, 0, 0, 0x00B8074A);
+#else
+      /* Use square color for details of black pieces */
+      oldBitmapTemp = SelectObject(hdcTemp, pieces[SOLID]);
+      oldBrushPiece = SelectObject(hdcMem, brushPiece);
+      BitBlt(hdcMem, x, y, SAMPLE_SQ_SIZE, SAMPLE_SQ_SIZE, 
+	     hdcTemp, 0, 0, 0x00B8074A);
+#endif
     }
     SelectObject(hdcMem, oldBrushPiece);
     SelectObject(hdcTemp, oldBitmapTemp);
@@ -369,7 +398,7 @@ PaintSampleSquare(
   SelectObject(hdcMem, oldBrushPiece);
   SelectObject(hdcMem, oldPen);
   DeleteObject(brushPiece);
-  DeleteObject(brushPieceOutline);
+  DeleteObject(brushPieceDetail);
   DeleteObject(brushSquare);
   DeleteObject(brushSquareOutline);
   DeleteObject(pen);
@@ -544,9 +573,9 @@ BoardOptionsDialog(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
     PaintColorBlock(hDlg, OPT_BlackPieceColor,  bpc);
     PaintColorBlock(hDlg, OPT_HighlightSquareColor, hsc);
     PaintColorBlock(hDlg, OPT_PremoveHighlightColor, phc);
-    PaintSampleSquare(hDlg, OPT_SampleLightSquare, lsc, wpc, hsc,
+    PaintSampleSquare(hDlg, OPT_SampleLightSquare, lsc, wpc, hsc, bpc,
 	TRUE, mono, pieces);
-    PaintSampleSquare(hDlg, OPT_SampleDarkSquare, dsc, bpc, phc,
+    PaintSampleSquare(hDlg, OPT_SampleDarkSquare, dsc, bpc, phc, wpc,
 	FALSE, mono, pieces);
 
     return FALSE;
@@ -605,42 +634,42 @@ BoardOptionsDialog(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
     case OPT_ChooseLightSquareColor:
       if (ChangeColor(hDlg, &lsc)) 
 	PaintColorBlock(hDlg, OPT_LightSquareColor, lsc);
-	PaintSampleSquare(hDlg, OPT_SampleLightSquare, lsc, wpc, hsc,
+	PaintSampleSquare(hDlg, OPT_SampleLightSquare, lsc, wpc, hsc, bpc,
 	    TRUE, mono, pieces);
       break;
 
     case OPT_ChooseDarkSquareColor:
       if (ChangeColor(hDlg, &dsc)) 
 	PaintColorBlock(hDlg, OPT_DarkSquareColor, dsc);
-	PaintSampleSquare(hDlg, OPT_SampleDarkSquare, dsc, bpc, phc,
+	PaintSampleSquare(hDlg, OPT_SampleDarkSquare, dsc, bpc, phc, wpc,
 	    FALSE, mono, pieces);
       break;
 
     case OPT_ChooseWhitePieceColor:
       if (ChangeColor(hDlg, &wpc)) 
 	PaintColorBlock(hDlg, OPT_WhitePieceColor, wpc);
-	PaintSampleSquare(hDlg, OPT_SampleLightSquare, lsc, wpc, hsc,
+	PaintSampleSquare(hDlg, OPT_SampleLightSquare, lsc, wpc, hsc, bpc,
 	    TRUE, mono, pieces);
       break;
 
     case OPT_ChooseBlackPieceColor:
       if (ChangeColor(hDlg, &bpc)) 
 	PaintColorBlock(hDlg, OPT_BlackPieceColor, bpc);
-	PaintSampleSquare(hDlg, OPT_SampleDarkSquare, dsc, bpc, phc,
+	PaintSampleSquare(hDlg, OPT_SampleDarkSquare, dsc, bpc, phc, wpc,
 	    FALSE, mono, pieces);
       break;
 
     case OPT_ChooseHighlightSquareColor:
       if (ChangeColor(hDlg, &hsc)) 
 	PaintColorBlock(hDlg, OPT_HighlightSquareColor, hsc);
-	PaintSampleSquare(hDlg, OPT_SampleLightSquare, lsc, wpc, hsc,
+	PaintSampleSquare(hDlg, OPT_SampleLightSquare, lsc, wpc, hsc, bpc,
 	    TRUE, mono, pieces);
       break;
 
     case OPT_ChoosePremoveHighlightColor:
       if (ChangeColor(hDlg, &phc)) 
 	PaintColorBlock(hDlg, OPT_PremoveHighlightColor, phc);
-	PaintSampleSquare(hDlg, OPT_SampleDarkSquare, dsc, bpc, phc,
+	PaintSampleSquare(hDlg, OPT_SampleDarkSquare, dsc, bpc, phc, wpc,
 	    FALSE, mono, pieces);
       break;
 
@@ -660,9 +689,9 @@ BoardOptionsDialog(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
       PaintColorBlock(hDlg, OPT_HighlightSquareColor, hsc);
       PaintColorBlock(hDlg, OPT_PremoveHighlightColor, phc);
       SetBoardOptionEnables(hDlg);
-      PaintSampleSquare(hDlg, OPT_SampleLightSquare, lsc, wpc, hsc,
+      PaintSampleSquare(hDlg, OPT_SampleLightSquare, lsc, wpc, hsc, bpc,
 	  TRUE, mono, pieces);
-      PaintSampleSquare(hDlg, OPT_SampleDarkSquare, dsc, bpc, phc,
+      PaintSampleSquare(hDlg, OPT_SampleDarkSquare, dsc, bpc, phc, wpc,
 	  FALSE, mono, pieces);
       break;
 
@@ -796,6 +825,8 @@ ColorizeTextDialog(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
     case IDOK:
       /* Read changed options from the dialog box */
       colorizeAttribs[cc] = mca;
+      textAttribs[cc].color = mca.color;
+      textAttribs[cc].effects = mca.effects;
       Colorize(currentColorClass, TRUE);
       if (cc == ColorNormal) {
 	CHARFORMAT cf;
@@ -874,7 +905,7 @@ IcsOptionsDialog(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
 
     mca = colorizeAttribs;
 
-    for (i=0; i <= NColorClasses - 1; i++) {
+    for (i=0; i < NColorClasses - 1; i++) {
       mca[i].color   = textAttribs[i].color;
       mca[i].effects = textAttribs[i].effects;
     }
@@ -1016,7 +1047,7 @@ IcsOptionsDialog(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
 	}
       }
 
-      for (i=0; i <= NColorClasses - 1; i++) {
+      for (i=0; i < NColorClasses - 1; i++) {
 	textAttribs[i].color   = mca[i].color;
 	textAttribs[i].effects = mca[i].effects;
       }
@@ -1095,7 +1126,7 @@ IcsOptionsDialog(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
       break;
 
     case OPT_DefaultColors:
-      for (i=0; i <= NColorClasses - 1; i++)
+      for (i=0; i < NColorClasses - 1; i++)
 	ParseAttribs(&mca[i].color, 
 		     &mca[i].effects,
 		     defaultTextAttribs[i]);
